@@ -55,7 +55,8 @@ struct dhcpc_state
   struct in_addr serverid;
   struct in_addr ipaddr;
   struct in_addr netmask;
-  struct in_addr dnsaddr;
+  struct in_addr dnsaddr[CONFIG_NETDB_DNSSERVER_NAMESERVERS];
+  uint8_t        num_dnsaddr;     /* Number of DNS addresses received */
   struct in_addr default_router;
   uint32_t       lease_time;      /* Lease expires in this number of seconds */
   uint32_t       renewal_time;    /* Seconds to transition to RENEW state(T1) */
