@@ -47,7 +47,7 @@
 #define NXSCOPE_CRC_LEN       (sizeof(uint16_t))
 
 /****************************************************************************
- * Private Type Definition
+ * Private Types
  ****************************************************************************/
 
 /* Nxscope serial protocol frame:
@@ -166,6 +166,16 @@ static int nxscope_frame_get(FAR struct nxscope_proto_s *p,
         }
     }
 
+  /* Check for no header */
+
+  if (hdr == NULL)
+    {
+      ret = -EINVAL;
+      goto errout;
+    }
+
+  /* Check for no SOF in header */
+
   if (hdr->sof != NXSCOPE_HDR_SOF)
     {
       ret = -EINVAL;
@@ -184,7 +194,7 @@ static int nxscope_frame_get(FAR struct nxscope_proto_s *p,
 
   /* Verify crc16 for the whole frame */
 
-  crc = crc16(&buff[i], hdr->len);
+  crc = crc16xmodem(&buff[i], hdr->len);
   if (crc != 0)
     {
       _err("ERROR: invalid crc16 %d\n", crc);
@@ -238,7 +248,7 @@ static int nxscope_frame_final(FAR struct nxscope_proto_s *p,
    *   final xor value = 0x0000
    */
 
-  crc = crc16(buff, *len);
+  crc = crc16xmodem(buff, *len);
 
 #ifdef CONFIG_ENDIAN_BIG
   buff[(*len)++] = (crc >> 0) & 0xff;
