@@ -1,6 +1,8 @@
 /****************************************************************************
  * apps/netutils/iperf/iperf.c
  *
+ * SPDX-License-Identifier: Apache-2.0
+ *
  * Licensed to the Apache Software Foundation (ASF) under one or more
  * contributor license agreements.  See the NOTICE file distributed with
  * this work for additional information regarding copyright ownership.  The
@@ -520,7 +522,7 @@ static int iperf_tcp_server(FAR struct iperf_ctrl_t *ctrl,
     {
       /* TODO need to change to non-block mode */
 
-      sockfd = accept(listen_socket, remote_addr, &addrlen);
+      sockfd = accept4(listen_socket, remote_addr, &addrlen, SOCK_CLOEXEC);
       if (sockfd < 0)
         {
           iperf_show_socket_error_reason("tcp server listen", listen_socket);
