@@ -41,7 +41,11 @@
 
 int main(int argc, FAR char *argv[])
 {
-  int ret = ntpc_stop();
+  int ret = OK;
+
+  printf("Stopping NTP client...\n");
+
+  ret = ntpc_stop();
   if (ret < 0)
     {
       fprintf(stderr, "ERROR: ntpc_stop() failed\n");
