@@ -82,7 +82,7 @@ static bool get_cpuset(const char *arg, cpu_set_t *cpu_set)
 
 int main(int argc, FAR char *argv[])
 {
-  char command[CONFIG_NSH_LINELEN];
+  char command[LINE_MAX];
   int exitcode;
   int option;
   int pid = -1;
@@ -153,7 +153,7 @@ int main(int argc, FAR char *argv[])
             }
 
           /* Construct actual command with args
-           * NOTE: total length does not exceed CONFIG_NSH_LINELEN
+           * NOTE: total length does not exceed LINE_MAX
            */
 
           for (i = 0; i < argc - 2; i++)
