@@ -198,7 +198,7 @@ static int test_regulator_resume(FAR struct regulator_dev_s *rdev)
   return 0;
 }
 
-static void test_regulator_register(FAR void **state)
+static void drivertest_reg_register(FAR void **state)
 {
   FAR struct regulator_dev_s *test = NULL;
 
@@ -213,7 +213,7 @@ static void test_regulator_register(FAR void **state)
   regulator_unregister(g_fake_regulator.rdev);
 }
 
-static void test_regulator_always_on(FAR void **state)
+static void drivertest_reg_always_on(FAR void **state)
 {
   FAR struct regulator_s *test = NULL;
   int ret = 0;
@@ -254,7 +254,7 @@ static void test_regulator_always_on(FAR void **state)
   return;
 }
 
-static void test_regulator_supply_1(FAR void **state)
+static void drivertest_reg_supply_always_on_boot_off(FAR void **state)
 {
   FAR struct regulator_s *test = NULL;
   int cnt = 10;
@@ -313,7 +313,7 @@ static void test_regulator_supply_1(FAR void **state)
   return;
 }
 
-static void test_regulator_supply_2(FAR void **state)
+static void drivertest_reg_supply_boot_on_always_on(FAR void **state)
 {
   FAR struct regulator_s *test = NULL;
   int cnt = 10;
@@ -372,7 +372,7 @@ static void test_regulator_supply_2(FAR void **state)
   return;
 }
 
-static void test_regulator_supply_3(FAR void **state)
+static void drivertest_reg_supply_boot_on_always_off(FAR void **state)
 {
   FAR struct regulator_s *test = NULL;
   int cnt = 10;
@@ -435,7 +435,7 @@ static void test_regulator_supply_3(FAR void **state)
   return;
 }
 
-static void test_regulator_supply_4(FAR void **state)
+static void drivertest_reg_supply_boot_off_always_off(FAR void **state)
 {
   FAR struct regulator_s *test = NULL;
   int cnt = 10;
@@ -495,7 +495,7 @@ static void test_regulator_supply_4(FAR void **state)
   return;
 }
 
-static void test_regulator_mode(FAR void **state)
+static void drivertest_reg_mode(FAR void **state)
 {
   FAR struct regulator_s *test = NULL;
   int cnt = 10;
@@ -535,7 +535,7 @@ static void test_regulator_mode(FAR void **state)
 }
 
 #ifdef CONFIG_PM
-static void test_regulator_pm_register(FAR void **state)
+static void drivertest_reg_pm_register(FAR void **state)
 {
   g_fake_regulator_desc.auto_lp = 0;
   g_fake_regulator.lpmode = REGULATOR_MODE_INVALID;
@@ -556,7 +556,7 @@ static void test_regulator_pm_register(FAR void **state)
   return;
 }
 
-static void test_regulator_pm_callback(FAR void **state)
+static void drivertest_reg_pm_callback(FAR void **state)
 {
   g_fake_regulator_desc.supply_name = NULL;
   g_fake_regulator_desc.auto_lp = 1;
@@ -611,16 +611,20 @@ int main(int argc, FAR char *argv[])
 {
   const struct CMUnitTest tests[] =
     {
-      cmocka_unit_test_prestate(test_regulator_register, NULL),
-      cmocka_unit_test_prestate(test_regulator_always_on, NULL),
-      cmocka_unit_test_prestate(test_regulator_supply_1, NULL),
-      cmocka_unit_test_prestate(test_regulator_supply_2, NULL),
-      cmocka_unit_test_prestate(test_regulator_supply_3, NULL),
-      cmocka_unit_test_prestate(test_regulator_supply_4, NULL),
-      cmocka_unit_test_prestate(test_regulator_mode, NULL),
+      cmocka_unit_test_prestate(drivertest_reg_register, NULL),
+      cmocka_unit_test_prestate(drivertest_reg_always_on, NULL),
+      cmocka_unit_test_prestate(drivertest_reg_supply_always_on_boot_off,
+                                NULL),
+      cmocka_unit_test_prestate(drivertest_reg_supply_boot_on_always_on,
+                                NULL),
+      cmocka_unit_test_prestate(drivertest_reg_supply_boot_on_always_off,
+                                NULL),
+      cmocka_unit_test_prestate(drivertest_reg_supply_boot_off_always_off,
+                                NULL),
+      cmocka_unit_test_prestate(drivertest_reg_mode, NULL),
 #ifdef CONFIG_PM
-      cmocka_unit_test_prestate(test_regulator_pm_register, NULL),
-      cmocka_unit_test_prestate(test_regulator_pm_callback, NULL),
+      cmocka_unit_test_prestate(drivertest_reg_pm_register, NULL),
+      cmocka_unit_test_prestate(drivertest_reg_pm_callback, NULL),
 #endif
     };
 
